import React from 'react';
import Taro from '@tarojs/taro';
import { View, Map, CoverView } from '@tarojs/components';
import { Icon } from '@antmjs/vantui'
import { getLocation } from '@/utils/authorize';
import iconPath from '@/assets/icons/marker.png';
import style from './style.module.less';

export default (props) => {
  const { readOnly, location, onChange } = props;

  const id = React.useMemo(() => `map-${Math.random().toString(36).substring(2, 10)}`, []);
  const mapCtxRef = React.useRef();

  const [
    // markers,
    center,
  ] = React.useMemo(() => {
    // eslint-disable-next-line no-undef
    const loc = location || DEFAULT_POS;
    const [longitude, latitude] = loc.split(',');

    // const mks = [{
    //   id: 1,
    //   longitude,
    //   latitude,
    //   iconPath,
    //   width: 17,
    //   height: 20
    // }];

    return [
      // mks,
      {longitude, latitude}
    ]
  }, [location]);

  const moveTo = (ctx, point) => {
    ctx.moveToLocation({
      ...point,
      fail: console.error,
    })
  }

  const getContext = React.useCallback(() => {
    const query = Taro.createSelectorQuery();
    query.select(`#${id}`).context(res => {
      mapCtxRef.current = res.context;

      // 修改中心图标 - 暂时不起作用, wx bug
      mapCtxRef.current.setLocMarkerIcon({
        iconPath,
        fail: console.error,
      })
    }).exec();
  }, [id]);

  const fixedLocation = () => {
    return new Promise((resolve) => {
      getLocation({ type: 'gcj02' }).then((res) => {
        resolve(res);
      }).catch((err) => {
        console.error(err);
        Taro.showToast({
          title: '定位失败',
          icon: 'none',
        })
      });
    });
  }

  const onRefresh = () => {
    if (mapCtxRef.current) {
      fixedLocation().then((res) => {
        const { longitude, latitude } = res;
        onChange([res.longitude, res.latitude].join(','));
        moveTo(mapCtxRef.current, {longitude, latitude});
      })
    }
  }
  
  React.useEffect(() => {
    if (!readOnly) {
      fixedLocation().then((res) => {
        const { longitude, latitude } = res;
        onChange([longitude, latitude].join(','));
      })
    }
  }, [readOnly]);

  React.useEffect(() => {
    getContext();
  }, [getContext]);

  return (
    <View className={style['map-wrapper']}>
      <Map
        id={id}
        showLocation
        longitude={center.longitude}
        latitude={center.latitude}
        // markers={markers}
      >
        {!readOnly && (
          <CoverView className={style['control']} onClick={onRefresh}>
            <Icon name="aim" size="24px" color="#1A7565" />
          </CoverView>
        )}
      </Map>
    </View>
  )
}
